highpymath
==========

High high-quality Python Math Library written in Rust and Python.

Features
========

Better precision
Better performance
Better readability

The Main Functions are Implemented in Rust, but you can not call direct the Rust Functions, this will do in Python written wrapper Functions.

The in Python Written Wrapper Functions gives you a gurenteed better performance and precision.